# -*- coding: utf-8 -*-

from rdkit import Chem

__author__="Armando Navarro Vázquez"
__copyright__="Copyright 2025, Armando Navarro-Vázquez"
__license__="MIT"
__version__="0.1"
__maintainer__="Armando Navarro-Vázquez"
__email_="armando.navarro@ufpe.br"
__status_="Development"

def ParseFile(file,format="sdf"):
  supplier = Chem.SDMolSupplier(file)
  conformers = [m for m in supplier if m is not None]
  return conformers



import platform

import os
from qmrun import qmparser
from qmrun import qmwriter
import sys
import subprocess


def help():
    print("Usage: qmrun file.sdf pre.txt post.txt")
    print("file.sdf:"," ","a V2000 SDF file containing initial geometries")
    print("pre.txt:"," ","a text file containing Orca keywords before *xyz block")
    print("A typical pre.txt file may look like:")
    print("!PAL8")
    print("B3LYP def2-SVP NMR")
    print("post.txt (optional):"," ","a text file containing Orca keywords after *xyz block")
    print("A typical post.txt file may look like:")
    print("%eprnmr\n","Nuclei = all\n","{ssfc}\n","SpinSpinRThresh\n","500.0\n","end")


def Run():
    filename = sys.argv[1]
    if len(sys.argv) < 3:
        help()
        exit(1)

    rootname=filename[0:filename.rfind(".")]
    if not os.path.exists(rootname):
      os.mkdir(rootname)
    conformers = qmparser.ParseFile(filename, format="sdf")
    print(len(conformers)," structures read from file")
    filestorun=[]
    postf=None
    minidx=None
    maxidx=None
    if len(sys.argv) > 3:
        postf=sys.argv[3]
    if len(sys.argv) > 4:
        minidx=int(sys.argv[4])
    if len(sys.argv) > 5:
        maxidx=int(sys.argv[5])
    if minidx == None:
        minidx=0
    if maxidx == None:
       maxidx=len(conformers)
    print("nconf=",len(conformers))
    for idx, mol in enumerate(conformers):
        if (idx+1) < minidx or (idx+1) > maxidx:
            continue
        fname = rootname + "_"+str(idx + 1)+".inp"
        fname=rootname+"/"+fname
        filestorun.append(fname[0:fname.rfind(".")])
        print(fname)
        wr = qmwriter.Writer(mol, fname, pre=sys.argv[2], post=postf)
        wr.Write()
    #and now run
    for f in filestorun:
        print("f=",f)
        arguments=[]
        print("arguments=",arguments)
        print(platform.system())
        if platform.system() != "Windows":
            arguments.append("qmrun-orca6")
        else:
            arguments.append("powershell")
            arguments.append("qmrun-orca6.ps1")
        arguments.append(f)
        print(arguments)
        subprocess.call(arguments)


if __name__ == "__main__":
    Run()



from rdkit import Chem
import platform

class Writer:
    def __init__(self, mol, filename, pre=None, post=None):
        self.mol = mol
        self.filename = filename
        self.molfile = None
        self.prefile = None
        self.postfile = None
        if pre:
            self.prefile = open(pre, "r")
        if post:
            self.postfile = open(post, "r")

    def Write(self):
        self.molfile=open(self.filename, "w")
        if self.prefile:
            lines = self.prefile.readlines()
            self.molfile.writelines(lines)
            if platform.system() == "Windows":
                self.molfile.write("\n")
        #write blannk
        self.molfile.write("*xyz 0 1\n")
        self.WriteMol()
        if self.postfile:
            lines = self.postfile.readlines()
            self.molfile.writelines(lines)
            self.molfile.write("\n")

        self.molfile.close()

    def WriteMol(self):
        conf = self.mol.GetConformer()
        for at in self.mol.GetAtoms():
            idx = at.GetIdx()
            xyz = conf.GetAtomPosition(idx)
            line = "{:<4}{:>12.6f}{:>12.6f}{:>12.6f}\n".format(str(at.GetSymbol()), xyz.x, xyz.y, xyz.z)
            self.molfile.write(line)
        self.molfile.write("*")
        self.molfile.write("\n")



from setuptools import setup
with open("README.md","r",encoding="utf-8") as f:
    readme = f.read()

setup(
    name='qmrun',
    version='0.1.4',
    description='Orca6 input file generator from SDF files',
    url='https://github.com/NMRDev/qmrun',
    author='Armando Navarro-Vázquez',
    author_email='armando.navarro@ufpe.br',
    license='MIT',
    packages=['qmrun'],
    install_requires=['rdkit',
                      ],
    classifiers=[
        'Development Status :: 1 - Planning',
        'Intended Audience :: Science/Research',
        'Programming Language :: Python :: 3',
    ],
    entry_points={
        'console_scripts': [
            'qmrun = qmrun:run',
        ]
    },

scripts=['bin/qmrun-orca6.ps1',
         'bin/qmrun-orca6',
         'bin/qmrun-orca6-stdout'],
long_description=readme, # A detailed description of the package
long_description_content_type="text/markdown", # The format of the long description
)


"""
qmrun.

A Orca6 Input File Generator from SDF files.
"""

from qmrun import qmdriver

__version__ = "0.1.4"
__author__ = 'Armando Navarro-Vázquez'
__credits__ = 'Armando Navarro-Vázquez. Universidade Federal de Pernambuco'

def run():
    qmdriver.Run()